@@ -14,7 +14,7 @@ _ = gettext.gettext
 class Revision(object):
     'Ask revision'
 
-    def __init__(self, revisions, revision=None, format_='%x %X.%f'):
+    def __init__(self, revisions, revision=None, format_='%x %H:%M:%S.%f'):
         self.parent = get_toplevel_window()
         self.win = gtk.Dialog(_('Revision'), self.parent,
             gtk.DIALOG_MODAL | gtk.DIALOG_DESTROY_WITH_PARENT,
@@ -30,8 +30,9 @@ class Revision(object):
         label = gtk.Label(_('Revision:'))
         hbox.pack_start(label, expand=True, fill=True)
         list_store = gtk.ListStore(str, str)
-        combobox = gtk.ComboBoxEntry(list_store)
-        self.entry = combobox.child
+        combobox = gtk.ComboBoxEntry()
+        combobox.set_model(list_store)
+        self.entry = combobox.get_child()
         self.entry.connect('focus-out-event', self.focus_out)
         self.entry.connect('activate', self.activate)
         label.set_mnemonic_widget(self.entry)
